@@ -1,4 +1,4 @@
-# Copyright 2020 Leibniz Information Centre for Economics
+# Copyright 2020-2021 Leibniz Information Centre for Economics
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,11 +14,14 @@
 
 
 def uncase_first_char(text: str) -> str:
-    return "({}|{}){}".format(
-        text[0].upper(),
-        text[0].lower(),
-        text[1:]
-        )
+    if text[0].isalpha():
+        return "({}|{}){}".format(
+            text[0].upper(),
+            text[0].lower(),
+            text[1:]
+            )
+    else:
+        return text
 
 
 def sentence_case_handler(text: str) -> str:
